@@ -10,6 +10,7 @@ use crate::components::{Appendable, ChildContainer};
 pub struct FileInput {
     children: Vec<Box<dyn Renderable>>,
     node: Node,
+    auto_submit: bool
 }
 
 impl NodeContainer for FileInput {
@@ -25,10 +26,18 @@ impl FileInput {
         FileInput {
             children: vec![],
             node: Node::default(),
+            auto_submit: false
         }
             .set_attr("id", &format!("file-input-{}", name))
             .set_attr("name", name)
     }
+
+    pub fn auto_submit(&mut self, is_auto_submit: bool) -> Self {
+        if is_auto_submit {
+            self.auto_submit = is_auto_submit;
+        }
+        self.clone()
+    }
 }
 
 
@@ -39,7 +48,9 @@ impl Renderable for FileInput {
             .add_class("file-input")
             .set_attr("type", "file")
             .tag("input");
-
+        if self.auto_submit {
+            file_input.set_attr("data-auto-submit", &self.auto_submit.to_string());
+        }
 
         let mut node = file_input.node;
 
